@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import collections
 from collections.abc import Callable, Sequence
 from numbers import Number
@@ -73,11 +75,15 @@ class ARFPlot:
         self.x_values = x_values
         self.attr_name = attr_name
 
-    def add_solutions(self, *solutions: BaseARF) -> None:
-        """Add solution to list of solutions for plotting
+    def add_solutions(
+        self, *solutions: BaseARF,
+        multicore: bool = False
+    ) -> None:
+        """Add solutions to list of solutions for plotting
 
         :param solutions: one or multiple solutions,
-            e.g. :class:`osaft.king1934.ARF()`
+               e.g. :class:`osaft.king1934.ARF()`
+        :param multicore: it ``True``, multiple processing
         """
         if len(solutions) == 0:
             out = 'is_computed_by() takes at least one positional argument '
@@ -91,7 +97,9 @@ class ARFPlot:
                     'overwritten. Consider renaming the '
                     f'attribute `name` of this solution({solution}).',
                 )
-            self._solutions[solution.name] = ARFData(solution)
+            self._solutions[solution.name] = ARFData(
+                solution, multicore=multicore,
+            )
 
     def remove_solution(self, solution: BaseARF) -> None:
         """Remove solution of list of solutions for plotting
