@@ -54,7 +54,7 @@ class ParticleScatteringPlot:
             inst: bool = True,
             phase: float = 0,
             mode: Optional[int] = None,
-            plot_disp: bool = True,
+            displacement: bool = True,
             symmetric: bool = True,
             tripcolor: bool = False,
             ax: Optional[plt.Axes] = None,
@@ -74,7 +74,7 @@ class ParticleScatteringPlot:
         :param inst: if `True` instantaneous amplitude is plotted
         :param phase: phase [0, 2 * pi]
         :param mode: mode of oscillation
-        :param plot_disp: if `True` displacement, else velocity plot
+        :param displacement: if `True` displacement, else velocity plot
         :param symmetric: if `True` the symmetry of the solution is used
         :param tripcolor: switches between tripcolor and tricontourf plot
         :param ax: Axes object
@@ -86,7 +86,7 @@ class ParticleScatteringPlot:
             inst=inst,
             phase=phase,
             mode=mode,
-            plot_disp=plot_disp,
+            displacement=displacement,
             symmetric=symmetric,
             ax=ax,
             **kwargs
@@ -97,7 +97,7 @@ class ParticleScatteringPlot:
             frames: int = 64,
             interval: float = 100.0,
             mode: Optional[int] = None,
-            plot_disp: bool = True,
+            displacement: bool = True,
             symmetric: bool = True,
             tripcolor: bool = False,
             ax: Optional[plt.Axes] = None,
@@ -118,7 +118,7 @@ class ParticleScatteringPlot:
         :param frames: number of frames for the animation
         :param interval: interval between frames in ms
         :param mode: mode of oscillation
-        :param plot_disp: if `True` displacement, else velocity plot
+        :param displacement: if `True` displacement, else velocity plot
         :param symmetric: if `True` the symmetry of the solution is used
         :param tripcolor: switches between tripcolor and tricontourf plot
         :param ax: Axes object
@@ -130,7 +130,7 @@ class ParticleScatteringPlot:
             frames=frames,
             interval=interval,
             mode=mode,
-            plot_disp=plot_disp,
+            displacement=displacement,
             symmetric=symmetric,
             ax=ax,
             **kwargs,
@@ -146,7 +146,7 @@ class ParticleScatteringPlot:
             inst: bool,
             phase: float,
             mode: Optional[int],
-            plot_disp: bool,
+            displacement: bool,
             symmetric: bool,
             ax: Optional[plt.Axes],
             **kwargs,
@@ -157,14 +157,14 @@ class ParticleScatteringPlot:
         :param inst: if `True` instantaneous amplitude is plotted
         :param phase: phase [0, 2 * pi]
         :param mode: mode of oscillation
-        :param plot_disp: if `True` displacement, else velocity plot
+        :param displacement: if `True` displacement, else velocity plot
         :param symmetric: if `True` the symmetry of the solution is used
         :param ax: Axes object
         :param kwargs: passed through to plotting method
         """
 
         # Data
-        if plot_disp:
+        if displacement:
             X, Z, C = self.data.get_displacement_magnitude(inst, phase, mode)
             cbar_label = 'Displacement [m]'
         else:
@@ -192,7 +192,7 @@ class ParticleScatteringPlot:
             frames: int,
             interval: float,
             mode: Optional[int],
-            plot_disp: bool,
+            displacement: bool,
             symmetric: bool,
             ax: Optional[plt.Axes],
             **kwargs,
@@ -203,7 +203,7 @@ class ParticleScatteringPlot:
         :param frames: number of frames for the animation
         :param interval: interval between frames in ms
         :param mode: mode of oscillation
-        :param plot_disp: if `True` displacement, else velocity plot
+        :param displacement: if `True` displacement, else velocity plot
         :param symmetric: if `True` the symmetry of the solution is used
         :param ax: Axes object
         :param kwargs: passed through to tricontourf()
@@ -217,18 +217,18 @@ class ParticleScatteringPlot:
             Closure is used to fix all additional parameters
             :param phase: phase
             """
-            if plot_disp:
+            if displacement:
                 return self.data.get_displacement_magnitude(True, phase, mode)
             else:
                 return self.data.get_velocity_magnitude(True, phase, mode)
         # Color bar label
-        if plot_disp:
+        if displacement:
             cbar_label = 'Displacement [m]'
         else:
             cbar_label = 'Velocity [m/s]'
 
         # Get norm
-        if plot_disp:
+        if displacement:
             _, _, C = self.data.get_displacement_magnitude(False, mode=mode)
         else:
             _, _, C = self.data.get_velocity_magnitude(False, mode=mode)
