@@ -44,7 +44,7 @@ class ARF(ScatteringField, BaseARF):
     :param eta_f: shear viscosity fluid [Pa s]
     :param zeta_f: bulk viscosity fluid [Pa s]
     :param p_0: Pressure amplitude of the field [Pa]
-    :param wave_type: Type of wave, travel(l)ing or standing
+    :param wave_type: Type of wave, traveling or standing
     :param position: Position within the standing wave field [m]
     :param small_viscous_boundary_layer: :math:`x_v \\gg 1`
     :param large_viscous_boundary_layer: :math:`x_v \\ll 1`
