@@ -5,8 +5,8 @@ import numpy as np
 from osaft import log
 from osaft.core.backgroundfields import WaveType
 from osaft.core.frequency import Frequency
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import LegendreFunctions as Leg
-from osaft.core.functions import SpecialFunctions as Sp
 from osaft.core.functions import exp
 from osaft.core.geometries import Sphere
 from osaft.core.helper import StringFormatter as SF
@@ -145,7 +145,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param n: mode
         :param arg: argument for spherical Bessel function
         """
-        return - Sp.bessely(n, arg) * arg ** (- n)
+        return - Bf.bessely(n, arg) * arg ** (- n)
 
     @staticmethod
     def psi_n(n: int, arg: float) -> complex:
@@ -156,7 +156,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param n: mode
         :param arg: argument for spherical Bessel function
         """
-        return Sp.besselj(n, arg) * arg ** (- n)
+        return Bf.besselj(n, arg) * arg ** (- n)
 
     def F_n(self, n: int, arg: float) -> float:
         """From King equation (30) and (31)
@@ -224,7 +224,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         """
         def Phi_n(n: int):
             num = - self.G_n(n, self.alpha)
-            num *= self.A_in(n) * Sp.hankelh2(n, r * self.k_f)
+            num *= self.A_in(n) * Bf.hankelh2(n, r * self.k_f)
             denom = self.G_n(n, self.alpha)
             denom += 1j * self.F_n(n, self.alpha)
             coefficient = num / denom
@@ -252,7 +252,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         :param t: time [s]
         """
         def Phi_n(n: int):
-            coefficient = self.A_in(n) * Sp.besselj(n, r * self.k_f)
+            coefficient = self.A_in(n) * Bf.besselj(n, r * self.k_f)
             out = exp(-1j * self.omega * t)
             out *= Leg.cos_monomial(n, theta, coefficient)
             return out
@@ -269,7 +269,7 @@ class ScatteringField(BaseKing, BaseScatteringRigidParticle, BaseScattering):
         """Implements :meth:`osaft.solutions.base_scattering.BaseScattering.\
 V_r_sc`
         """
-        return self.A_dash_n(n) * self.k_f * Sp.d1_hankelh2(n, self.k_f * r)
+        return self.A_dash_n(n) * self.k_f * Bf.d1_hankelh2(n, self.k_f * r)
 
     def V_theta_sc(
         self, n: int,
@@ -278,7 +278,7 @@ V_r_sc`
         """Implements :meth:`osaft.solutions.base_scattering.BaseScattering.\
 V_theta_sc`
         """
-        return self.A_dash_n(n) * Sp.hankelh2(n, self.k_f * r) / r
+        return self.A_dash_n(n) * Bf.hankelh2(n, self.k_f * r) / r
 
 
 if __name__ == '__main__':
