@@ -2,7 +2,7 @@ import unittest
 
 from osaft import WaveType, gorkov1962, king1934, yosioka1955
 from osaft.core.backgroundfields import WrongWaveTypeError
-from osaft.core.functions import SpecialFunctions as Sp
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.core.functions import conj, pi, sin
 from osaft.tests.basetest import BaseTest
 from osaft.tests.basetest_arf import HelperCompareARF
@@ -106,13 +106,13 @@ class TestARF(BaseTest):
     def M_n(self, n):
         B_n = self.cls.B_n(n)
         x_s = self.cls.x_s
-        return (-1) ** n / (2 * n + 1) * B_n * Sp.besselj(n, x_s)
+        return (-1) ** n / (2 * n + 1) * B_n * Bf.besselj(n, x_s)
 
     def K_n(self, n):
         B_n = self.cls.B_n(n)
         k_s = self.cls.k_s
         x_s = self.cls.x_s
-        return (-1) ** n / (2 * n + 1) * B_n * k_s * Sp.d1_besselj(n, x_s)
+        return (-1) ** n / (2 * n + 1) * B_n * k_s * Bf.d1_besselj(n, x_s)
 
     def compute_arf(self):
         a = self.R_0
@@ -278,7 +278,7 @@ class TestCompareToGorkov(BaseTest, HelperCompareARF):
             self.p_0, self.wave_type, self.position,
         )
 
-        # Setting size of the particle particle to be small
+        # Setting size of the particle to be small
         self.R_0 = self.cls.fluid.lambda_f * 1e-4
         self._R_0.high = self.cls.fluid.lambda_f * 1e-3
 
@@ -306,7 +306,7 @@ class TestCompareToSmallParticle(BaseTest, HelperCompareARF):
             self.p_0, self.wave_type, self.position, small_particle=True,
         )
 
-        # Setting size of the particle particle to be small
+        # Setting size of the particle to be small
         self.R_0 = self.cls.fluid.lambda_f * 1e-4
         self._R_0.high = self.cls.fluid.lambda_f * 1e-3
 
@@ -334,7 +334,7 @@ class TestCompareSmallBubble(BaseTest, HelperCompareARF):
             small_particle=True, bubble_solution=True,
         )
 
-        # Setting size of the particle particle to be small
+        # Setting size of the particle to be small
         self.R_0 = self.cls.fluid.lambda_f * 1e-4
         self._R_0.high = self.cls.fluid.lambda_f * 1e-3
 
