@@ -1,7 +1,7 @@
 import unittest
 
 from osaft import king1934, yosioka1955
-from osaft.core.functions import SpecialFunctions as SF
+from osaft.core.functions import BesselFunctions as Bf
 from osaft.tests.basetest import BaseTest
 from osaft.tests.basetest_scattering import (
     HelperCompareScattering,
@@ -40,10 +40,10 @@ class TestScattering(BaseTest, HelperScattering):
         k_s = self.cls.k_s
         x_f = self.R_0 * k_f
         x_s = self.R_0 * k_s
-        j = lambda x: SF.besselj(n, x)
-        dj = lambda x: SF.d1_besselj(n, x)
-        h = lambda x: SF.hankelh2(n, x)
-        dh = lambda x: SF.d1_hankelh2(n, x)
+        j = lambda x: Bf.besselj(n, x)
+        dj = lambda x: Bf.d1_besselj(n, x)
+        h = lambda x: Bf.hankelh2(n, x)
+        dh = lambda x: Bf.d1_hankelh2(n, x)
 
         A_num = lamb * k_f * j(x_s) * dj(x_f) - k_s * dj(x_s) * j(x_f)
         A_denom = k_s * dj(x_s) * h(x_f) - lamb * k_f * j(x_s) * dh(x_f)
@@ -58,10 +58,10 @@ class TestScattering(BaseTest, HelperScattering):
         k_s = self.cls.k_s
         x_f = self.cls.x_f
         x_s = self.cls.x_s
-        j = lambda x: SF.besselj(n, x)
-        dj = lambda x: SF.d1_besselj(n, x)
-        h = lambda x: SF.hankelh2(n, x)
-        dh = lambda x: SF.d1_hankelh2(n, x)
+        j = lambda x: Bf.besselj(n, x)
+        dj = lambda x: Bf.d1_besselj(n, x)
+        h = lambda x: Bf.hankelh2(n, x)
+        dh = lambda x: Bf.d1_hankelh2(n, x)
 
         B_num = 1j * k_f
         B_denom = k_s * dj(x_s) * h(x_f)
@@ -74,19 +74,19 @@ class TestScattering(BaseTest, HelperScattering):
     def V_r_sc(self, n, r):
         A_n = self.cls.A_n(n)
         k_f = self.cls.k_f
-        return k_f * A_n * SF.d1_hankelh2(n, k_f * r)
+        return k_f * A_n * Bf.d1_hankelh2(n, k_f * r)
 
     def V_theta_sc(self, n, r):
         A_n = self.cls.A_n(n)
         k_f = self.cls.k_f
-        return A_n * SF.hankelh2(n, k_f * r) / r
+        return A_n * Bf.hankelh2(n, k_f * r) / r
 
     def radial_particle_velocity(self, r, theta, t, mode) -> float:
 
         def radial_func(l, x):
             k = self.cls.k_s
             B = self.cls.B_n(l)
-            j = SF.d1_besselj(l, k * x)
+            j = Bf.d1_besselj(l, k * x)
             return B * k * j
 
         return self.cls.radial_mode_superposition(
@@ -99,7 +99,7 @@ class TestScattering(BaseTest, HelperScattering):
         def radial_func(l, x):
             k = self.cls.k_s
             B = self.cls.B_n(l)
-            j = SF.besselj(l, k * x)
+            j = Bf.besselj(l, k * x)
             return B * j / r
 
         return self.cls.tangential_mode_superposition(
